#!/bin/sh

set -e

# This is an install/update script for DebianParl
# DebianParl Homepage: https://wiki.debian.org/DebianParl
# Source of this code: git://git.debian.org/parl/blends

# Workaround for dictionaries-common install failure (bug#751367)
aptitude install apt-utils

# Administration
#  * include automated maintenance routines
# Console media
#  * include core ALSA audio tools
#  * exclude MIDI patches
#  * exclude GStreamer
#  * include PulseAudio audio daemon
# Console mobile
#  * include SyncEvolution console tool and http service
# Desktop
#  * include desktop helper tools
#  * include the lightweight Xfce desktop
#  * include Xfce power management tools
#  * include screensaver unicode-screensaver
#  * include desktop editor Mousepad
#  * include desktop crypto helper tools
# Desktop email
#  * include Icedove email with sieve plugin
#  * include Icedove PGP plugin
# Desktop media
#  * include simple ALSA volume control Volti
#  * include PulseAudio desktop volume control
#  * include mplayer2, with desktop and web browser wrappers
# desktop-mobile
#  * include SyncEvolution desktop tool
# Desktop office
#  * include LibreOffice core for GTK+
#  * include LibreOffice Writer
#  * include LibreOffice Calc
#  * include LibreOffice Impress
#  * include Evince PDF reader
# Desktop photo
#  * include photo manager Shotwell
# Desktop scheduling
#  * include Icedove extension Iceowl
# Desktop web
#  * include Iceweasel web browser
#  * include Iceweasel security plugins
# Hardware
#  * include OpenGL hardware rasterizers (excluding software rasterizer)
#  * exclude webkit library (used only for maybe-risky PAC proxy parsing)
#  * include low-level crypto tools
aptitude install task-laptop acpi-support acpi-support-base alsa-utils aptitude bash-completion bluetooth cpufrequtils enigmail evince-gtk evolution-data-server gecko-mediaplayer gnome-disk-utility gvfs haveged icedove iceowl-extension iceweasel libgl1-mesa-dri libreoffice-calc libreoffice-gtk libreoffice-impress libreoffice-ogltrans libreoffice-style-tango libreoffice-writer lightdm mousepad mplayer2 network-manager-gnome ntp parcimonie pavucontrol pulseaudio pulseaudio-esound-compat shotwell sync-ui syncevolution syncevolution-http tango-icon-theme task-laptop unattended-upgrades unicode-screensaver usermode uuid-runtime volti xfce4-power-manager xfce4-power-manager-plugins xfce4-session xserver-xorg xul-ext-certificatepatrol xul-ext-cookie-monster xul-ext-flashblock xul-ext-noscript xul-ext-refcontrol xul-ext-requestpolicy xul-ext-sieve \
 bluez-cups- bluez-gstreamer- cups- epdfview- freepats- gstreamer0.10-ffmpeg- gstreamer0.10-plugins-bad- gstreamer0.10-plugins-base- gstreamer0.10-plugins-good- gstreamer0.10-pulseaudio- hpijs- hplip- libgl1-mesa-swx11- libreoffice- libreoffice-base- libreoffice-emailmerge- libreoffice-java-common- libreoffice-report-builder-bin- libreoffice-style-galaxy- libwebkitgtk-1.0-0- printer-driver-all- xfce4-volumed-

# Administration
#  * include APT frontend aptitude
#  * define routines to resolve package dependencies
#  * fix mark auto-installed essential packages + dependencies (bug#742977)
#  * fix mark auto-installed misc. packages relevant only as dependencies
#  * define routines to make backup of and help edit config files
#  * auto-repair inconsistent filesystems during boot
# Desktop
#  * silence confusing panel question at initial login
#  * replace appfinder with mail-reader in default panel
#  * disable storing session at logout by default
# Hardware
#  * sleep when lid is closed
#  * modernize logic of radio on/off button
set -e;\
 _setvar /etc/default/acpi-support LID_SLEEP true;\
 _setvar /etc/default/acpi-support WIRELESS_BLUETOOTH_SYNC true;\
 _pkgdeps(){ set -e;\
  dpkg-query \
    -Wf=',$''{Pre-Depends},$''{Depends},$''{Recommends}\n' $* 2>/dev/null \
    | sed -r \
    -e 's/[,|] *([a-z0-9.+-]+)?(:\s+)?( *[^|,]*)?/\1\n/g' \
    | sed '/^$/d'|sort -u; };\
 _pkg2re(){ set -e;\
  echo $* \
    | sed -r \
    -e 's/\s+/\|/g;' \
    -e 's/^\|//;' \
    -e 's/([.+-])/\\\1/g;' \
    -e 's/\|$//'; };\
 _pkgreal(){ set -e;\
  dpkg-query \
    -Wf='$''{Package},$''{Provides},\n' \
    | sed -r \
    -e '/,,/d;' \
    -e 's/^([a-z0-9.+-]+).*[,|] *('"$(_pkg2re $*)"')[ :,]/\1/;' \
    -e '/,/d'; };\
 _pkganddeepdeps(){ set -e;\
  rest=$*;\
  all=$rest;\
  for i in 1 2 3 4 5; do \
    deps=$(_pkgdeps $rest);\
    rest="$deps $(_pkgreal $deps)";\
    all="$all $rest";\
  done;\
  echo $all \
    | sed -r \
    -e 's/\s+/\n/g' \
    | sort -u; };\
 _pkgessentials(){ set -e;\
  dpkg-query \
    -Wf='$''{Package}%$''{Essential}\n' \
    | sed -r \
    -e 's/(.*)%yes/\1/;' \
    -e '/%/d'; };\
 apt-mark auto \
  $(_pkganddeepdeps $(_pkgessentials) apt linux-image-*);\
 apt-mark auto \
  acpi-support-base aptitude-common bash-completion bluetooth evolution-data-server grub-common gvfs isc-dhcp-common lightdm-gtk-greeter tasksel-data uuid-runtime vim-common xserver-xorg;\
 _backup(){ set -e;\
  if [ -e "$1.orig" ]; then \
    :;\
  elif [ -e "$1" ]; then \
    cp -a "$1" "$1.orig";\
  else \
    touch "$1.orig";\
  fi; };\
 _clone(){ set -e;\
  _backup "$2";\
  cp -a "$1" "$2"; };\
 _setvar(){ set -e;\
  _backup "$1";\
  sed -i -r \
    -e "s,^#?($2)=.*,\\1=$3," "$1"; };\
 _setvar /etc/default/rcS FSCKFIX yes;\
 cd /etc/xdg/xfce4/xfconf/xfce-perchannel-xml;\
 _clone ../../panel/default.xml xfce4-panel.xml;\
 sed -i -r \
  -e 's,xfce4-appfinder,exo-mail-reader,' \
  xfce4-panel.xml;\
 _backup xfce4-session.xml;\
 sed -i -r \
  -e 's,(<property name="general"[^>]*>),\1\n    <property name="SaveOnExit" type="bool" value="false"/>,' \
  xfce4-session.xml
